@@ -1,7 +1,10 @@
 from pywr.core import Model, Storage, Link, ScenarioIndex, Timestep, Output
 from pywr.parameters import ConstantParameter, DailyProfileParameter, load_parameter
-from pywr.parameters.control_curves import ControlCurveParameter, ControlCurveInterpolatedParameter, \
-    ControlCurvePiecewiseInterpolatedParameter
+from pywr.parameters.control_curves import (
+    ControlCurveParameter,
+    ControlCurveInterpolatedParameter,
+    ControlCurvePiecewiseInterpolatedParameter,
+)
 from pywr.parameters._control_curves import _interpolate
 from pywr.recorders import NumpyArrayNodeRecorder, NumpyArrayStorageRecorder, assert_rec
 import numpy as np
@@ -13,36 +16,45 @@ import os
 from fixtures import simple_linear_model, simple_storage_model
 from helpers import load_model
 
+
 @pytest.fixture
 def model(simple_storage_model):
-    """ Modified simple_storage_model to be steady-state. """
-    i = simple_storage_model.nodes['Input']
+    """Modified simple_storage_model to be steady-state."""
+    i = simple_storage_model.nodes["Input"]
     i.max_flow = 0
-    o = simple_storage_model.nodes['Output']
+    o = simple_storage_model.nodes["Output"]
     o.max_flow = 0
-    s = simple_storage_model.nodes['Storage']
+    s = simple_storage_model.nodes["Storage"]
     s.max_volume = 100.0
     return simple_storage_model
 
 
-@pytest.mark.parametrize("configuration, expected_value", [
-    ((0.0, 0.0, 1.0, 50.0, 100.0), 50.0),
-    ((1.0, 0.0, 1.0, 50.0, 100.0), 100.0),
-    ((0.5, 0.0, 1.0, 50.0, 100.0), 75.0),
-    ((0.0, 0.5, 1.0, 50.0, 100.0), 50.0),
-    ((0.75, 0.5, 1.0, 50.0, 100.0), 75.0),
-])
+@pytest.mark.parametrize(
+    "configuration, expected_value",
+    [
+        ((0.0, 0.0, 1.0, 50.0, 100.0), 50.0),
+        ((1.0, 0.0, 1.0, 50.0, 100.0), 100.0),
+        ((0.5, 0.0, 1.0, 50.0, 100.0), 75.0),
+        ((0.0, 0.5, 1.0, 50.0, 100.0), 50.0),
+        ((0.75, 0.5, 1.0, 50.0, 100.0), 75.0),
+    ],
+)
 def test_interpolation(configuration, expected_value):
     current_position, lower_bound, upper_bound, lower_value, upper_value = configuration
-    assert _interpolate(current_position, lower_bound, upper_bound, lower_value, upper_value) == expected_value
+    assert (
+        _interpolate(
+            current_position, lower_bound, upper_bound, lower_value, upper_value
+        )
+        == expected_value
+    )
 
 
 class TestPiecewiseControlCurveParameter:
-    """Tests for ControlCurveParameter """
+    """Tests for ControlCurveParameter"""
 
     @staticmethod
     def _assert_results(m, s):
-        """ Correct results for the following tests """
+        """Correct results for the following tests"""
 
         @assert_rec(m, s.cost)
         def expected_func(timestep, scenario_index):
@@ -59,42 +71,43 @@ class TestPiecewiseControlCurveParameter:
             s.initial_volume = initial_volume
             m.run()
 
-
     def test_with_values(self, model):
         """Test with `values` keyword argument"""
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
         # Return 10.0 when above 0.0 when below
         s.cost = ControlCurveParameter(m, s, [0.8, 0.6], [1.0, 0.7, 0.4])
         self._assert_results(m, s)
 
     def test_with_parameters(self, model):
-        """ Test with `parameters` keyword argument. """
+        """Test with `parameters` keyword argument."""
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
         # Two different control curves
         cc = [ConstantParameter(model, 0.8), ConstantParameter(model, 0.6)]
         # Three different parameters to return
         params = [
-            ConstantParameter(model, 1.0), ConstantParameter(model, 0.7), ConstantParameter(model, 0.4)
+            ConstantParameter(model, 1.0),
+            ConstantParameter(model, 0.7),
+            ConstantParameter(model, 0.4),
         ]
         s.cost = ControlCurveParameter(model, s, cc, parameters=params)
 
         self._assert_results(m, s)
 
     def test_values_load(self, model):
-        """ Test load of float lists. """
+        """Test load of float lists."""
 
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
         data = {
             "type": "controlcurve",
             "control_curves": [0.8, 0.6],
             "values": [1.0, 0.7, 0.4],
-            "storage_node": "Storage"
+            "storage_node": "Storage",
         }
 
         s.cost = p = load_parameter(model, data)
@@ -102,38 +115,26 @@ class TestPiecewiseControlCurveParameter:
         self._assert_results(m, s)
 
     def test_parameters_load(self, model):
-        """ Test load of parameter lists for 'control_curves' and 'parameters' keys. """
+        """Test load of parameter lists for 'control_curves' and 'parameters' keys."""
 
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
         data = {
             "type": "controlcurve",
             "storage_node": "Storage",
             "control_curves": [
-                {
-                    "type": "constant",
-                    "value": 0.8
-                },
-                {
-                    "type": "monthlyprofile",
-                    "values": [0.6]*12
-                }
+                {"type": "constant", "value": 0.8},
+                {"type": "monthlyprofile", "values": [0.6] * 12},
             ],
             "parameters": [
                 {
                     "type": "constant",
                     "value": 1.0,
                 },
-                {
-                    "type": "constant",
-                    "value": 0.7
-                },
-                {
-                    "type": "constant",
-                    "value": 0.4
-                }
-            ]
+                {"type": "constant", "value": 0.7},
+                {"type": "constant", "value": 0.4},
+            ],
         }
 
         s.cost = p = load_parameter(model, data)
@@ -141,12 +142,12 @@ class TestPiecewiseControlCurveParameter:
         self._assert_results(m, s)
 
     def test_single_cc_load(self, model):
-        """ Test load from dict with 'control_curve' key
+        """Test load from dict with 'control_curve' key
 
         This is different to the above test by using singular 'control_curve' key in the dict
         """
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
         data = {
             "type": "controlcurve",
@@ -171,14 +172,14 @@ class TestPiecewiseControlCurveParameter:
             m.run()
 
     def test_with_nonstorage(self, model):
-        """ Test usage on non-`Storage` node. """
+        """Test usage on non-`Storage` node."""
         # Now test if the parameter is used on a non storage node
         m = model
-        s = m.nodes['Storage']
+        s = m.nodes["Storage"]
 
-        l = Link(m, 'Link')
+        l = Link(m, "Link")
         # Connect the link node to the network to create a valid model
-        o = m.nodes['Output']
+        o = m.nodes["Output"]
         s.connect(l)
         l.connect(o)
 
@@ -199,12 +200,12 @@ class TestPiecewiseControlCurveParameter:
             m.run()
 
     def test_with_nonstorage_load(self, model):
-        """ Test load from dict with 'storage_node' key. """
+        """Test load from dict with 'storage_node' key."""
         m = model
-        s = m.nodes['Storage']
-        l = Link(m, 'Link')
+        s = m.nodes["Storage"]
+        l = Link(m, "Link")
         # Connect the link node to the network to create a valid model
-        o = m.nodes['Output']
+        o = m.nodes["Output"]
         s.connect(l)
         l.connect(o)
 
@@ -212,7 +213,7 @@ class TestPiecewiseControlCurveParameter:
             "type": "controlcurve",
             "control_curve": 0.8,
             "values": [10.0, 0.0],
-            "storage_node": "Storage"
+            "storage_node": "Storage",
         }
 
         l.cost = p = load_parameter(model, data)
@@ -237,8 +238,8 @@ def test_control_curve_interpolated(model, use_parameters):
     m = model
     m.timestepper.delta = 200
 
-    s = m.nodes['Storage']
-    o = m.nodes['Output']
+    s = m.nodes["Storage"]
+    o = m.nodes["Output"]
     s.connect(o)
 
     cc = ConstantParameter(model, 0.8)
@@ -247,7 +248,9 @@ def test_control_curve_interpolated(model, use_parameters):
     if use_parameters:
         # Create the parameter using parameters for the values
         parameters = [ConstantParameter(model, v) for v in values]
-        s.cost = p = ControlCurveInterpolatedParameter(model, s, cc, parameters=parameters)
+        s.cost = p = ControlCurveInterpolatedParameter(
+            model, s, cc, parameters=parameters
+        )
     else:
         # Create the parameter using a list of values
         s.cost = p = ControlCurveInterpolatedParameter(model, s, cc, values)
@@ -261,11 +264,17 @@ def test_control_curve_interpolated(model, use_parameters):
         elif c == 0.0 and v == 0.0:
             expected = values[1]
         else:
-            expected = np.interp(v/100.0, [0.0, c, 1.0], values[::-1])
+            expected = np.interp(v / 100.0, [0.0, c, 1.0], values[::-1])
         return expected
 
     for control_curve in (0.0, 0.8, 1.0):
-        cc.set_double_variables(np.array([control_curve,]))
+        cc.set_double_variables(
+            np.array(
+                [
+                    control_curve,
+                ]
+            )
+        )
         for initial_volume in (0.0, 10.0, 50.0, 80.0, 90.0, 100.0):
             s.initial_volume = initial_volume
             model.run()
@@ -291,6 +300,7 @@ def test_control_curve_interpolated_json(use_parameters):
         volume_factor = reservoir1._current_pc[si.global_id]
         cc = control_curve[timestep.index]
         return np.interp(volume_factor, [0.0, cc, 1.0], values[::-1])
+
     model.run()
 
 
@@ -310,6 +320,7 @@ def test_circular_control_curve_interpolated_json():
         volume_factor = reservoir1._current_pc[si.global_id]
         cc = control_curve[timestep.index]
         return np.interp(volume_factor, [0.0, cc, 1.0], values[::-1])
+
     model.run()
 
 
@@ -338,17 +349,23 @@ def test_demand_saving_with_indexed_array():
     demand_baseline = 50.0
     demand_factor = 0.9  # jan-apr
     demand_saving = 1.0
-    assert_allclose(rec_demand.data[0, 0], demand_baseline * demand_factor * demand_saving)
+    assert_allclose(
+        rec_demand.data[0, 0], demand_baseline * demand_factor * demand_saving
+    )
 
     # first control curve breached
     demand_saving = 0.95
-    assert(rec_storage.data[4, 0] < (0.8 * max_volume) )
-    assert_allclose(rec_demand.data[5, 0], demand_baseline * demand_factor * demand_saving)
+    assert rec_storage.data[4, 0] < (0.8 * max_volume)
+    assert_allclose(
+        rec_demand.data[5, 0], demand_baseline * demand_factor * demand_saving
+    )
 
     # second control curve breached
     demand_saving = 0.5
-    assert(rec_storage.data[11, 0] < (0.5 * max_volume) )
-    assert_allclose(rec_demand.data[12, 0], demand_baseline * demand_factor * demand_saving)
+    assert rec_storage.data[11, 0] < (0.5 * max_volume)
+    assert_allclose(
+        rec_demand.data[12, 0], demand_baseline * demand_factor * demand_saving
+    )
 
 
 def test_demand_saving_with_indexed_array_from_hdf():
@@ -384,9 +401,10 @@ def test_demand_saving_with_indexed_array_from_hdf():
 
 
 class TestControlCurvePiecewiseInterpolatedParameter:
-    """Tests for `ControlCurvePiecewiseInterpolatedParameter` """
+    """Tests for `ControlCurvePiecewiseInterpolatedParameter`"""
+
     def test_single_control_curve(self, simple_storage_model):
-        """Test `ControlCurvePiecewiseInterpolatedParameter` with one control curve. """
+        """Test `ControlCurvePiecewiseInterpolatedParameter` with one control curve."""
         model = simple_storage_model
         storage_node = model.nodes["Storage"]
         input_node = model.nodes["Input"]
@@ -396,8 +414,9 @@ class TestControlCurvePiecewiseInterpolatedParameter:
             ConstantParameter(model, 0.5),
         ]
 
-        parameter = ControlCurvePiecewiseInterpolatedParameter(model, storage_node, control_curves,
-                                                               [(500, 200), (100, 50)], name="CCPIP")
+        parameter = ControlCurvePiecewiseInterpolatedParameter(
+            model, storage_node, control_curves, [(500, 200), (100, 50)], name="CCPIP"
+        )
         assert parameter.minimum == 0.0
         assert parameter.maximum == 1.0
 
@@ -410,7 +429,7 @@ class TestControlCurvePiecewiseInterpolatedParameter:
 
         model.timestepper.start = "1920-01-01"
         model.timestepper.delta = 1
-        model.timestepper.end = model.timestepper.start + model.timestepper.offset*100
+        model.timestepper.end = model.timestepper.start + model.timestepper.offset * 100
 
         @assert_rec(model, parameter)
         def expected_func(timestep, scenario_index):
@@ -428,7 +447,7 @@ class TestControlCurvePiecewiseInterpolatedParameter:
         model.run()
 
     def test_two_control_curves(self, simple_storage_model):
-        """Test `ControlCurvePiecewiseInterpolatedParameter` with two control curves. """
+        """Test `ControlCurvePiecewiseInterpolatedParameter` with two control curves."""
         model = simple_storage_model
         storage_node = model.nodes["Storage"]
         input_node = model.nodes["Input"]
@@ -439,8 +458,13 @@ class TestControlCurvePiecewiseInterpolatedParameter:
             ConstantParameter(model, 0.25),
         ]
 
-        parameter = ControlCurvePiecewiseInterpolatedParameter(model, storage_node, control_curves,
-                                                               [(500, 200), (100, 50), (0, -100)], name="CCPIP")
+        parameter = ControlCurvePiecewiseInterpolatedParameter(
+            model,
+            storage_node,
+            control_curves,
+            [(500, 200), (100, 50), (0, -100)],
+            name="CCPIP",
+        )
         assert parameter.minimum == 0.0
         assert parameter.maximum == 1.0
 
@@ -453,7 +477,7 @@ class TestControlCurvePiecewiseInterpolatedParameter:
 
         model.timestepper.start = "1920-01-01"
         model.timestepper.delta = 1
-        model.timestepper.end = model.timestepper.start + model.timestepper.offset*100
+        model.timestepper.end = model.timestepper.start + model.timestepper.offset * 100
 
         @assert_rec(model, parameter)
         def expected_func(timestep, scenario_index):
@@ -484,7 +508,7 @@ class TestControlCurvePiecewiseInterpolatedParameter:
             "control_curves": ["cc1", "cc2"],
             "minimum": 0.2,
             "maximum": 0.7,
-            "values": [[200, 100], [10, 5], [0, -10]]
+            "values": [[200, 100], [10, 5], [0, -10]],
         }
         parameter = load_parameter(model, parameter_data)
         assert parameter.minimum == 0.2
